==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebColumnSelectionEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnSelectionEventArgsDetailDescription } from "./WebColumnSelectionEventArgsDetailDescription";
/**
 * @hidden
 */
var WebColumnSelectionEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnSelectionEventArgsDetailDescriptionMetadata, _super);
    function WebColumnSelectionEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnSelectionEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebColumnSelectionEventArgsDetailDescriptionMetadata.a == null) {
            WebColumnSelectionEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnSelectionEventArgsDetailDescriptionMetadata.c(WebColumnSelectionEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebColumnSelectionEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebColumnSelectionEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnSelectionEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ColumnSelectionEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("OldSelection", "Array:string");
        a.item("NewSelection", "Array:string");
        a.item("Added", "Array:string");
        a.item("Removed", "Array:string");
    };
    WebColumnSelectionEventArgsDetailDescriptionMetadata.d = function (a) {
        WebColumnSelectionEventArgsDetailDescriptionMetadata.b(a);
        a.aa("WebColumnSelectionEventArgsDetail", function () { return new WebColumnSelectionEventArgsDetailDescription(); });
        a.z("WebColumnSelectionEventArgsDetail", WebColumnSelectionEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnSelectionEventArgsDetailDescriptionMetadata.$t = markType(WebColumnSelectionEventArgsDetailDescriptionMetadata, 'WebColumnSelectionEventArgsDetailDescriptionMetadata');
    WebColumnSelectionEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnSelectionEventArgsDetailDescriptionMetadata;
}(Base));
export { WebColumnSelectionEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebColumnSelectionEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnSelectionEventArgsDetailDescription } from "./WebColumnSelectionEventArgsDetailDescription";
/**
 * @hidden
 */
var WebColumnSelectionEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnSelectionEventArgsDetailDescriptionMetadata, _super);
    function WebColumnSelectionEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnSelectionEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebColumnSelectionEventArgsDetailDescriptionMetadata.a == null) {
            WebColumnSelectionEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnSelectionEventArgsDetailDescriptionMetadata.c(WebColumnSelectionEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebColumnSelectionEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebColumnSelectionEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnSelectionEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ColumnSelectionEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("OldSelection", "Array:string");
        a.item("NewSelection", "Array:string");
        a.item("Added", "Array:string");
        a.item("Removed", "Array:string");
    };
    WebColumnSelectionEventArgsDetailDescriptionMetadata.d = function (a) {
        WebColumnSelectionEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebColumnSelectionEventArgsDetail", function () { return new WebColumnSelectionEventArgsDetailDescription(); });
        a.ab("WebColumnSelectionEventArgsDetail", WebColumnSelectionEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnSelectionEventArgsDetailDescriptionMetadata.$t = markType(WebColumnSelectionEventArgsDetailDescriptionMetadata, 'WebColumnSelectionEventArgsDetailDescriptionMetadata');
    WebColumnSelectionEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnSelectionEventArgsDetailDescriptionMetadata;
}(Base));
export { WebColumnSelectionEventArgsDetailDescriptionMetadata };
